Index: trunk/BNC/bncwindow.cpp
===================================================================
--- trunk/BNC/bncwindow.cpp	(revision 1681)
+++ trunk/BNC/bncwindow.cpp	(revision 1682)
@@ -174,5 +174,5 @@
   _ephV3CheckBox->setCheckState(Qt::CheckState(settings.value("ephV3").toInt()));
 
   // Ephemeris Corrections Options
   // -----------------------------
   _corrPathLineEdit    = new QLineEdit(settings.value("corrPath").toString());
@@ -382,5 +382,5 @@
   aogroup->addTab(ogroup,tr("RINEX Observations"));
   aogroup->addTab(egroup,tr("RINEX Ephemeris"));
-  aogroup->addTab(cgroup,tr("Ephemeris Corrections"));
+  aogroup->addTab(cgroup,tr("Broadcast Corrections"));
   aogroup->addTab(sgroup,tr("Feed Engine"));
   aogroup->addTab(sergroup,tr("Serial Link"));
@@ -504,5 +504,5 @@
   }   
 
-  // Ephemeris Corrections
+  // Broadcast Corrections
   // ---------------------
   QGridLayout* cLayout = new QGridLayout;
@@ -1349,5 +1349,5 @@
   }
 
-  // Ephemeris Corrections
+  // Broadcast Corrections
   // ---------------------
   if (aogroup->currentIndex() == 4) {
@@ -174,5 +174,5 @@
   _ephV3CheckBox->setCheckState(Qt::CheckState(settings.value("ephV3").toInt()));
 
-  // Ephemeris Corrections Options
+  // Broadcast Corrections Options
   // -----------------------------
   _corrPathLineEdit    = new QLineEdit(settings.value("corrPath").toString());
